TweetyPy
========

TweetyPy is a direct descendant of the FEX frequency excursion calculator.
Frequency excursion is the first (and only in v1) analysis that TweetyPy is
capable of, but there are plans for adding several additional calculations
starting with trill rate and bandwidth followed by multi-song comparisons for
similarity and eventually clustering and categorizations.

The current code is still in an alpha state.  This means it should only be used
for testing and cannot be considered reliable for analyses yet.  Please report
any bugs, but do not be surprised if this_ happens while using the alpha/beta
releases.

.. _this: https://www.youtube.com/watch?v=iWtohHwNXoU

